#
# spec file for package libofx
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libofx
Version:        0.9.10
Release:        6.1
Summary:        OFX Command Parser and API
License:        GPL-2.0+
Group:          Development/Libraries/Other
Url:            http://libofx.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/libofx/libofx/0.9.10/%{name}-%{version}.tar.gz
BuildRequires:  curl-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libxml++-devel
BuildRequires:  opensp-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LibOFX is a parser and API designed to allow applications to support
OFX command responses, usually provided by financial institutions for
statement downloads. The author says, "To my knowledge, it is the first
working OpenSource implementations of the OFX (Open Financial eXchange)
specification on the client side. This project was first started as my
end of degree project, with the goal of adding OFX support to GnuCash.
It has since evolved into a generic library, so all OpenSource
Financial software can benefit from it."

%package -n libofx6
Summary:        OFX Command Parser and API
Group:          Development/Libraries/Other
Requires:       %{name} >= %{version}

%description -n libofx6
LibOFX is a parser and API designed to allow applications to support
OFX command responses, usually provided by financial institutions for
statement downloads. The author says, "To my knowledge, it is the first
working OpenSource implementations of the OFX (Open Financial eXchange)
specification on the client side. This project was first started as my
end of degree project, with the goal of adding OFX support to GnuCash.
It has since evolved into a generic library, so all OpenSource
Financial software can benefit from it."

%package devel
Summary:        OFX Command Parser and API
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       glibc-devel

%description devel
LibOFX is a parser and API designed to allow applications to support
OFX command responses, usually provided by financial institutions for
statement downloads. The author says, "To my knowledge, it is the first
working OpenSource implementations of the OFX (Open Financial eXchange)
specification on the client side. This project was first started as my
end of degree project, with the goal of adding OFX support to GnuCash.
It has since evolved into a generic library, so all OpenSource
Financial software can benefit from it."

%prep
%setup -q
chmod -x doc/ofx_sample_files/ofx_spec160_stmtrs_example.sgml

%build
%configure --disable-static --with-pic --with-opensp-libs=%{_libdir}
make %{?_smp_mflags} docdir=%{_defaultdocdir}/%{name}

%install
%make_install
mkdir -p %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/libofx %{buildroot}%{_defaultdocdir}/%{name}
rm %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
cp -a doc/ofx_sample_files/*.* %{buildroot}%{_defaultdocdir}/%{name}/
cp -a doc/html %{buildroot}%{_defaultdocdir}/%{name}/
%fdupes %{buildroot}
rm -f %{buildroot}%{_libdir}/*.la

%post -n libofx6 -p /sbin/ldconfig

%postun -n libofx6 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/[ACNR]*
%doc %{_defaultdocdir}/%{name}/*.txt
%{_bindir}/*
%{_datadir}/libofx/
%{_mandir}/man1/*.1%{?ext_man}

%files -n libofx6
%defattr (-, root, root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}/html/
%doc %{_defaultdocdir}/%{name}/*.sgml
%doc %{_defaultdocdir}/%{name}/*.xml
%{_libdir}/*.so
%{_includedir}/libofx/
%{_libdir}/pkgconfig/libofx.pc

%clean
rm -rf %{buildroot}

%changelog
* Fri Jan 30 2015 zaitor@opensuse.org
- Update to version 0.9.10:
  + Fix missing balance dates (ledger_balance_date,
    available_balance_date).
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 0.9.9:
  + Fix missing increment of SO_CURRENT number in libofx-0.9.6 to
    avoid crashes when mixing this with older applications.
  + bug#41: Fix a crash that occurs while importing a possibly
    invalid OFX file.
- Rename libofx5 subpackage to libofx6, following the soname bump.
- Delete backup files that should not be in the tarball.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 0.9.8:
  + Fix errorneous reading of files with empty lines.
  + bug#24: Fix build error on solaris.
  + bug#40: Fix compiler warnings of OFX clang
- Changes from versiom 0.9.7:
  + Fix errorneous reading of files with long lines.
* Mon Apr  1 2013 zaitor@opensuse.org
- Update to version 0.9.6:
  + Extend buffer for TRANSACTION_NAME to 96 bytes due to UTF-8
    multibyte characters.
  + Fix typo in info message.
  + Allow lines longer than 1024 caracters.
  + Fix treatment of empty date strings: Must return a zero date
    instead of a bogus one.
  + Replace unlink() with remove() to fix compile problems with
    gcc 4.7
  + Make configure fail if gengetopt is missing and generated files
    are not present.
  + Fix garbled character encoding for UTF-8 encoded OFX 2.0 (XML)
    files. Sadly, because of a bug in OpenSP with xml decoding this
    currently means that iso-8859-1 OFX-2.0 files will still not be
    properly decoded.
- Drop libofx-gcc47.patch, fixed upstream.
* Wed Mar 14 2012 dimstar@opensuse.org
- Add libofx-gcc47.patch: Fix build with gcc 4.7.
* Wed Jan 11 2012 dimstar@opensuse.org
- Update to version 0.9.5:
  + Workaround OFX files specifying invalid encoding values
    (specifically:  UNICODE and CP1252). This should fix most
    encoding problems reported.
  + Look for DTD in source directory (simplifies developpement)
  + Add minor argument checking
  + Expose field: OfxSecurityData::fiid in API
  + Make string arguments a const reference where appropriate
  + Add configure check for help2man tool
  + Improve build system and autoconf 2.68 compatibility
  + Improve generated man pages
  + Use GCC's -fvisibility=hidden to hide internal symbols from
    external users.
- Rename libofx4 subpackage to libofx5, following the soname bump.
- Clean spec-file using spec-cleaner.
* Thu Jul 28 2011 vuntz@opensuse.org
- Fix build by not marking some non-directory files as %%dir in file
  list. This was wrong but only breaks now with newer rpm.
* Fri Jun 17 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 0.9.4:
  + Fix segfault on some malformed date formats.
  + LibOFX will now look for DTDs in env variable OFX_DTD_PATH.
  + Better handling of paths (tolerates trailing path separator,
    or lack thereof)
  + No longer ignore return value of mkstemp()
  + Move to LibXML++ 2.6, as 1.0 is deprecated
  + Add generated man pages with html2man
- Changes from version 0.9.3:
  + sf#2969817: Fix segfault on some files containing missing
    closing tags.
- Changes from version 0.9.2:
  + Win32: Look up the dtd installation directory from the current
    executable's location.
  + Fix a crash on invalid date format
  + Allow wrapping the library in python.
  + Fix "Transaction posting date off by one"
  + Various C++ include fixes for building with recent compilers.
- Drop libofx-0.8.2-gcc43.patch: fixed upstream.
- Use source services: download_url, recompress, set_version.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Feb 10 2009 vuntz@novell.com
- Update to version 0.9.1:
  + Add more sanity checks on string length
  + Fix gnucash crash on OFX files with non-ascii characters and
    very long lines (bgo#528306)
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 0.9.0:
  * Export version information thus allowing depending apps to
    determine the version of libOFX it is compiled against
  * Some fields have been added to OfxFiLogin to allow for
    modification of some OFX header fields in outgoing requests
  * Calling apps can now tell libofx where the data field resides
  * Some warnings for recent versions of GCC have been fixed
  * LibOFX can now easily be cross-compiled for Windows on Linux
  * The OFX header is now scanned for a hint regarding the encoding
    of the document and convert the data to UTF8 if iconv is
    available at compile time
  * The API for online requests has been cleaned up
- Rename libofx3 to libofx4
* Tue Nov 13 2007 mauro@suse.de
- bug fixes for the gcc 4.3 issue.
* Thu Oct  4 2007 maw@suse.de
- Split out a libofx3 subpackage
- Add %%post and %%postun sections
- Minor specfile cleanups.
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.8.2:
  * bug fixes for GCC4.x and 64-bit compatibility
  * fix to enable OFXDirectConnect in Aqbanking
  * improvements to ofxpartner functionality
  * minor build system modifications
  * new fields for fees, commissions and stock split data
  * fix a memory leak and a potential crashing bug
- Developer documentation moved to devel subpackage.
* Wed May 10 2006 sbrabec@suse.cz
- Split devel subpackage.
- Fixed dependencies.
- Enabled parallel build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 ro@suse.de
- fix typo in makefile (LIBOBJ -> LIBOBJS)
* Wed Oct 19 2005 sbrabec@suse.cz
- Updated to version 0.8.0.
* Mon Apr 25 2005 gekker@suse.de
- Add libofx-gcc4.patch to fix GCC4 complilation.
* Mon Feb 21 2005 sbrabec@suse.cz
- Updated to version 0.7.0.
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 0.6.6.
* Thu Jun 12 2003 kukuk@suse.de
- Add missing directories to filelist
* Sun Jun  1 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Feb 17 2003 sf@suse.de
- added path to libopensp
* Fri Feb  7 2003 hhetter@suse.de
- initial package
